
RELEASE_VERSION='0.3.899446293'
BUILD_DATE='Wed Jun 14 09:17:24 UTC 2023'
BUILD_MACHINE_INFO='Linux runner-5w-mmpfk-project-28359933-concurrent-09pp22 5.4.235-144.344.amzn2.x86_64 #1 SMP Sun Mar 12 12:50:22 UTC 2023 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='4470585723'
GIT_COMMIT_SHA='fd8ec9f80c05a9db9d83ed9aa57a0035aa566445'
GIT_BRANCH='main'
